#
# spec file for package tealdeer
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tealdeer
Version:        1.6.1
Release:        2.3
Summary:        An implementation of tldr in Rust
License:        Apache-2.0 OR MIT
Group:          Productivity/Other
URL:            https://github.com/dbrgn/tealdeer
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        cargo_config
# Instructions on how to generate vendor.tar.xz
Source3:        README.packager
BuildRequires:  cargo-packaging
BuildRequires:  cmake
BuildRequires:  libopenssl-devel
BuildRequires:  rust
BuildRequires:  rust-std
BuildRequires:  zlib-devel

ExclusiveArch:  %{rust_tier1_arches}

%description
An implementation of tldr in Rust. It has example based and community-driven man pages.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and bash-completion)
Requires:       bash-completion
BuildArch:      noarch

%description bash-completion
Bash command-line completion support for %{name}.

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
Requires:       fish
BuildArch:      noarch

%description    fish-completion
Fish command-line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       zsh
BuildArch:      noarch

%description    zsh-completion
Zsh command-line completion support for %{name}.

%prep
%setup -qa1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
%{cargo_install}
install -Dm644 -T ./completion/bash_tealdeer %{buildroot}%{_datadir}/bash-completion/completions/tealdeer
install -Dm644 -T ./completion/fish_tealdeer %{buildroot}%{_datadir}/fish/vendor_completions.d/tealdeer.fish
install -Dm644 -T ./completion/zsh_tealdeer  %{buildroot}%{_datadir}/zsh/site-functions/_tealdeer

%files
%doc README.md
%license LICENSE-MIT LICENSE-APACHE
%{_bindir}/tldr

%files bash-completion
%{_datadir}/bash-completion/*

%files fish-completion
%dir %{_datadir}/fish
%{_datadir}/fish/*

%files zsh-completion
%dir %{_datadir}/zsh
%{_datadir}/zsh/*

%changelog
* Fri Apr 14 2023 William Brown <william.brown@suse.com>
- bsc#1210365 - CVE-2023-26964 - hyper,h2: stream stacking when H2 processing HTTP2 RST_STREAM frames
* Sun Nov  6 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.6.1:
  * Run cargo update (#299)
  * Fix path source for custom pages dir (#297)
  * Docs: improve grammar (#296)
  * Run cargo update (#291)
  * Remove deprecated -m/--markdown command
  * Remove deprecated -o/--os command
  * Remove deprecated --config-path command
* Wed Oct  5 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Enable changesgenerate in _service.
- Add shell completions for fish, bash-completion, and zsh.
- Update to version 1.6.0:
  * Release v1.6.0
  * Run cargo update (#291)
  * Remove deprecated -m/--markdown command
  * Remove deprecated -o/--os command
  * Remove deprecated --config-path command
  * Lazy creation of cache directory
  * Impl From<RawX> for more config types
  * Cache: Add pages_dir helper method
* Tue Aug  2 2022 William Brown <william.brown@suse.com>
- Limit to T1 arches to prevent build failures
* Mon Jun 20 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue May 24 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue Apr  5 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Fri Jan  7 2022 William Brown <william.brown@suse.com>
- Version 1.5.0
  - Custom pages and patches
  - Change argument parsing from docopt to clap
  - Multi-language support
  - A new --show-paths command
  - Compliance with the tldr client spec v1.5
  - Docs
- resolve bsc#1194119 (CVE-2021-45710)
- Add support for cargo_vendor and obs_scm
* Fri Nov  5 2021 William Brown <william.brown@suse.com>
- Add cargo audit service to detect potential security issues
* Sat May  1 2021 Jonathan Papineau <jonathan@jpapineau.ca>
- Version 1.4.1
  - [fixed] Syntax error in zsh completion file
- Version 1.4.0
  - [added] Configurable automatic cache updates
  - [added] Improved color detection and support for --color argument and NO_COLOR env variable
  - [changed] Make --list option comply with official spec
  - [changed] Move cache age warning to stderr
* Thu Apr  9 2020 Dany Marcoux <dmarcoux@suse.com>
- Version 1.3.0
  - Compact output mode
  - Raw rendering mode
  - Zsh autocompletion
  - And more... see upstream
- Pass "no-track" option to "cargo install" to avoid generating
  ".crates2.json"
* Tue Oct 15 2019 Dany Marcoux <dmarcoux@suse.com>
- Instruct packager to install cargo directly from the cargo package
* Tue Oct  1 2019 Dany Marcoux <dmarcoux@suse.com>
- Use `pwd`/.cargo for vendor config so that CARGO_HOME export is
  not required (thanks to luke_nukem for this)
* Tue Sep 24 2019 Dany Marcoux <dmarcoux@suse.com>
- Version 1.2.0
  - Add support for spaces in commands
  - Add pager support
  - Print detected OS with -v / --version
  - Add (back) support for proxies
- Set directory for 'git clone' in README.packager
- Add '--path .' to 'cargo install' command to install the binaries for the
  package in current working directory.
* Sun Apr 28 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias from descriptions. Remove double %%setup.
* Wed Apr 24 2019 Dany Marcoux <dmarcoux@suse.com>
- Initial packaging at 1.1.0
